@@ -361,7 +361,7 @@ static void delete_tokens(tokenset *x){
  **
  ******************************************************************/
 
-static int token_ends_with(char *token, char *ends_in){
+/* static int token_ends_with(char *token, char *ends_in){
   
   int tokenlength = strlen(token);
   int ends_length = strlen(ends_in);
@@ -369,7 +369,7 @@ static int token_ends_with(char *token, char *ends_in){
   char *tmp_ptr;
   
   if (tokenlength <= ends_length){
-    /* token string is too short so can't possibly end with ends */
+    // token string is too short so can't possibly end with ends 
     return 0;
   }
   
@@ -383,7 +383,7 @@ static int token_ends_with(char *token, char *ends_in){
     return 0;
   }
 }
-
+*/
 
 /******************************************************************
  **
