@@ -24,6 +24,7 @@
  ** Feb 13, 2008 - fix problems with generic_get_detailed_header_info(), gzgeneric_get_detailed_header_info()
  ** May 18, 2009 - Add Ability to extract scan date from CEL file header
  ** Sep 19, 2013 - Improve ability to deal with large 64bit matrices
+ ** Sept 4, 2017 - change gzFile * to gzFile
  **
  *************************************************************/
 #include <R.h>
@@ -705,10 +706,7 @@ int check_generic_cel_file(const char *filename, const char *ref_cdfName, int re
 
 int read_genericcel_file_intensities(const char *filename, double *intensity, size_t chip_num, size_t rows, size_t cols, size_t chip_dim_rows){
 
-  size_t i=0, j=0;
-  size_t cur_index;
-  
-  int fread_err=0;
+  size_t i=0;
   
   FILE *infile;
 
@@ -755,10 +753,7 @@ int read_genericcel_file_intensities(const char *filename, double *intensity, si
 
 int read_genericcel_file_stddev(const char *filename, double *intensity, size_t chip_num, size_t rows, size_t cols, size_t chip_dim_rows){
 
-  size_t i=0, j=0;
-  size_t cur_index;
-  
-  int fread_err=0;
+  size_t i=0;
   
   FILE *infile;
 
@@ -809,10 +804,7 @@ int read_genericcel_file_stddev(const char *filename, double *intensity, size_t
 
 int read_genericcel_file_npixels(const char *filename, double *intensity, size_t chip_num, size_t rows, size_t cols, size_t chip_dim_rows){
 
-  size_t i=0, j=0;
-  size_t cur_index;
-  
-  int fread_err=0;
+  size_t i=0;
   
   FILE *infile;
 
@@ -871,10 +863,7 @@ void generic_get_masks_outliers(const char *filename, int *nmasks, short **masks
 
 
 
-  int i=0, j=0;
-  int cur_index;
-  
-  int fread_err=0;
+  int i=0;
   
   FILE *infile;
 
@@ -960,13 +949,12 @@ void generic_get_masks_outliers(const char *filename, int *nmasks, short **masks
 void generic_apply_masks(const char *filename, double *intensity, size_t chip_num, size_t rows, size_t cols, size_t chip_dim_rows, int rm_mask, int rm_outliers){
 
 
-  size_t i=0, j=0;
+  size_t i=0;
   size_t cur_index;
   
   short cur_x, cur_y;
 
 
-  int fread_err=0;
   int nrows;
   int size;
 
@@ -1060,7 +1048,7 @@ void generic_apply_masks(const char *filename, double *intensity, size_t chip_nu
 
 int isgzGenericCelFile(const char *filename){
 
-  gzFile *infile;
+  gzFile infile;
   generic_file_header file_header;
   generic_data_header data_header;
   
@@ -1099,7 +1087,7 @@ int isgzGenericCelFile(const char *filename){
 
 char *gzgeneric_get_header_info(const char *filename, int *dim1, int *dim2){
 
-  gzFile *infile;
+  gzFile infile;
   generic_file_header file_header;
   generic_data_header data_header;
 
@@ -1159,7 +1147,7 @@ char *gzgeneric_get_header_info(const char *filename, int *dim1, int *dim2){
 
 void gzgeneric_get_detailed_header_info(const char *filename, detailed_header_info *header_info){
   
-  gzFile *infile;
+  gzFile infile;
   generic_file_header file_header;
   generic_data_header data_header;
   nvt_triplet *triplet;
@@ -1646,7 +1634,7 @@ int check_gzgeneric_cel_file(const char *filename, const char *ref_cdfName, int
   int dim1, dim2;
 
 
-  gzFile *infile;
+  gzFile infile;
   generic_file_header file_header;
   generic_data_header data_header;
   
@@ -1709,12 +1697,9 @@ int check_gzgeneric_cel_file(const char *filename, const char *ref_cdfName, int
 
 int gzread_genericcel_file_intensities(const char *filename, double *intensity, size_t chip_num, size_t rows, size_t cols, size_t chip_dim_rows){
 
-  size_t i=0, j=0;
-  size_t cur_index;
+  size_t i=0;
   
-  int fread_err=0;
-  
-  gzFile *infile;
+  gzFile infile;
 
   generic_file_header my_header;
   generic_data_header my_data_header;
@@ -1760,12 +1745,9 @@ int gzread_genericcel_file_intensities(const char *filename, double *intensity,
 
 int gzread_genericcel_file_stddev(const char *filename, double *intensity, size_t chip_num, size_t rows, size_t cols, size_t chip_dim_rows){
 
-  size_t i=0, j=0;
-  size_t cur_index;
+  size_t i=0;
   
-  int fread_err=0;
-  
-  gzFile *infile;
+  gzFile infile;
 
   generic_file_header my_header;
   generic_data_header my_data_header;
@@ -1814,12 +1796,9 @@ int gzread_genericcel_file_stddev(const char *filename, double *intensity, size_
 
 int gzread_genericcel_file_npixels(const char *filename, double *intensity, size_t chip_num, size_t rows, size_t cols, size_t chip_dim_rows){
 
-  size_t i=0, j=0;
-  size_t cur_index;
+  size_t i=0;
   
-  int fread_err=0;
-  
-  gzFile *infile;
+  gzFile infile;
 
   generic_file_header my_header;
   generic_data_header my_data_header;
@@ -1879,12 +1858,9 @@ void gzgeneric_get_masks_outliers(const char *filename, int *nmasks, short **mas
 
 
 
-  int i=0, j=0;
-  int cur_index;
+  int i=0;
   
-  int fread_err=0;
-  
-  gzFile *infile;
+  gzFile infile;
 
   generic_file_header my_header;
   generic_data_header my_data_header;
@@ -1968,17 +1944,16 @@ void gzgeneric_get_masks_outliers(const char *filename, int *nmasks, short **mas
 void gzgeneric_apply_masks(const char *filename, double *intensity, size_t chip_num, size_t rows, size_t cols, size_t chip_dim_rows, int rm_mask, int rm_outliers){
 
 
-  size_t i=0, j=0;
+  size_t i=0;
   size_t cur_index;
   
   short cur_x, cur_y;
 
 
-  int fread_err=0;
   int nrows;
   int size;
 
-  gzFile *infile;
+  gzFile infile;
 
   generic_file_header my_header;
   generic_data_header my_data_header;
